@@ -3,11 +3,13 @@ pub(crate) mod contexts;
 pub(crate) mod cronjobs;
 pub(crate) mod daemonsets;
 pub(crate) mod deployments;
+pub(crate) mod dynamic;
 pub(crate) mod ingress;
 pub(crate) mod jobs;
 pub(crate) mod key_binding;
 pub(crate) mod metrics;
 pub(crate) mod models;
+pub(crate) mod network_policies;
 pub(crate) mod nodes;
 pub(crate) mod ns;
 pub(crate) mod pods;
@@ -35,11 +37,13 @@ use self::{
   cronjobs::KubeCronJob,
   daemonsets::KubeDaemonSet,
   deployments::KubeDeployment,
+  dynamic::{KubeDynamicKind, KubeDynamicResource},
   ingress::KubeIngress,
   jobs::KubeJob,
   key_binding::DEFAULT_KEYBINDING,
   metrics::KubeNodeMetrics,
   models::{LogsState, ScrollableTxt, StatefulList, StatefulTable, TabRoute, TabsState},
+  network_policies::KubeNetworkPolicy,
   nodes::KubeNode,
   ns::KubeNs,
   pods::{KubeContainer, KubePod},
@@ -79,6 +83,7 @@ pub enum ActiveBlock {
   Jobs,
   DaemonSets,
   CronJobs,
+  DynamicResource,
   Secrets,
   RplCtrl,
   StorageClasses,
@@ -89,8 +94,10 @@ pub enum ActiveBlock {
   Ingress,
   Pvc,
   Pv,
+  NetworkPolicies,
   ServiceAccounts,
   More,
+  DynamicView,
 }
 
 #[derive(Clone, Eq, PartialEq, Debug)]
@@ -152,7 +159,10 @@ pub struct Data {
   pub ingress: StatefulTable<KubeIngress>,
   pub pvcs: StatefulTable<KubePVC>,
   pub pvs: StatefulTable<KubePV>,
+  pub nw_policies: StatefulTable<KubeNetworkPolicy>,
   pub service_accounts: StatefulTable<KubeSvcAcct>,
+  pub dynamic_kinds: Vec<KubeDynamicKind>,
+  pub dynamic_resources: StatefulTable<KubeDynamicResource>,
 }
 
 /// selected data items
@@ -161,6 +171,7 @@ pub struct Selected {
   pub pod: Option<String>,
   pub container: Option<String>,
   pub context: Option<String>,
+  pub dynamic_kind: Option<KubeDynamicKind>,
 }
 
 /// Holds main application state
@@ -174,6 +185,7 @@ pub struct App {
   pub main_tabs: TabsState,
   pub context_tabs: TabsState,
   pub more_resources_menu: StatefulList<(String, ActiveBlock)>,
+  pub dynamic_resources_menu: StatefulList<(String, ActiveBlock)>,
   pub show_info_bar: bool,
   pub is_loading: bool,
   pub is_streaming: bool,
@@ -208,6 +220,7 @@ impl Default for Data {
         pod: None,
         container: None,
         context: None,
+        dynamic_kind: None,
       },
       logs: LogsState::new(String::default()),
       describe_out: ScrollableTxt::new(),
@@ -233,7 +246,10 @@ impl Default for Data {
       ingress: StatefulTable::new(),
       pvcs: StatefulTable::new(),
       pvs: StatefulTable::new(),
+      nw_policies: StatefulTable::new(),
       service_accounts: StatefulTable::new(),
+      dynamic_kinds: vec![],
+      dynamic_resources: StatefulTable::new(),
     }
   }
 }
@@ -350,25 +366,36 @@ impl Default for App {
             id: RouteId::Home,
           },
         },
+        TabRoute {
+          title: format!(
+            "Dynamic {}",
+            DEFAULT_KEYBINDING.jump_to_dynamic_resources.key
+          ),
+          route: Route {
+            active_block: ActiveBlock::DynamicView,
+            id: RouteId::Home,
+          },
+        },
       ]),
       more_resources_menu: StatefulList::with_items(vec![
-        ("Cron Jobs".into(), ActiveBlock::CronJobs),
+        ("CronJobs".into(), ActiveBlock::CronJobs),
         ("Secrets".into(), ActiveBlock::Secrets),
-        ("Replication Controllers".into(), ActiveBlock::RplCtrl),
-        ("Persistent Volume Claims".into(), ActiveBlock::Pvc),
-        ("Persistent Volumes".into(), ActiveBlock::Pv),
-        ("Storage Classes".into(), ActiveBlock::StorageClasses),
+        ("ReplicationControllers".into(), ActiveBlock::RplCtrl),
+        ("PersistentVolumeClaims".into(), ActiveBlock::Pvc),
+        ("PersistentVolumes".into(), ActiveBlock::Pv),
+        ("StorageClasses".into(), ActiveBlock::StorageClasses),
         ("Roles".into(), ActiveBlock::Roles),
-        ("Role Bindings".into(), ActiveBlock::RoleBindings),
-        ("Cluster Roles".into(), ActiveBlock::ClusterRoles),
+        ("RoleBindings".into(), ActiveBlock::RoleBindings),
+        ("ClusterRoles".into(), ActiveBlock::ClusterRoles),
         (
-          "Cluster Role Bindings".into(),
+          "ClusterRoleBindings".into(),
           ActiveBlock::ClusterRoleBinding,
         ),
-        ("Service Accounts".into(), ActiveBlock::ServiceAccounts),
+        ("ServiceAccounts".into(), ActiveBlock::ServiceAccounts),
         ("Ingresses".into(), ActiveBlock::Ingress),
-        // ("Network Policies".into(), ActiveBlock::RplCtrl),
+        ("NetworkPolicies".into(), ActiveBlock::NetworkPolicies),
       ]),
+      dynamic_resources_menu: StatefulList::new(),
       show_info_bar: true,
       is_loading: false,
       is_streaming: false,
@@ -544,6 +571,7 @@ impl App {
   pub async fn cache_all_resource_data(&mut self) {
     self.dispatch(IoEvent::GetNamespaces).await;
     self.dispatch(IoEvent::GetPods).await;
+    self.dispatch(IoEvent::DiscoverDynamicRes).await;
     self.dispatch(IoEvent::GetServices).await;
     self.dispatch(IoEvent::GetNodes).await;
     self.dispatch(IoEvent::GetConfigMaps).await;
@@ -564,6 +592,7 @@ impl App {
     self.dispatch(IoEvent::GetPvcs).await;
     self.dispatch(IoEvent::GetPvs).await;
     self.dispatch(IoEvent::GetServiceAccounts).await;
+    self.dispatch(IoEvent::GetNetworkPolicies).await;
     self.dispatch(IoEvent::GetMetrics).await;
   }
 
@@ -629,6 +658,9 @@ impl App {
       ActiveBlock::ServiceAccounts => {
         self.dispatch(IoEvent::GetServiceAccounts).await;
       }
+      ActiveBlock::DynamicResource => {
+        self.dispatch(IoEvent::GetDynamicRes).await;
+      }
       ActiveBlock::Logs => {
         if !self.is_streaming {
           // do not tail to avoid duplicates
@@ -700,7 +732,6 @@ mod test_utils {
 
   pub fn convert_resource_from_file<K: Serialize, T>(filename: &str) -> (Vec<T>, Vec<K>)
   where
-    <K as Resource>::DynamicType: Default,
     K: Clone + DeserializeOwned + fmt::Debug,
     K: Resource,
     T: KubeResource<K> + From<K>,
@@ -715,7 +746,6 @@ mod test_utils {
 
   pub fn load_resource_from_file<K>(filename: &str) -> ObjectList<K>
   where
-    <K as Resource>::DynamicType: Default,
     K: Clone + DeserializeOwned + fmt::Debug,
     K: Resource,
   {
@@ -769,6 +799,10 @@ mod tests {
     assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetKubeConfig);
     assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetNamespaces);
     assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetPods);
+    assert_eq!(
+      sync_io_rx.recv().await.unwrap(),
+      IoEvent::DiscoverDynamicRes
+    );
     assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetServices);
     assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetNodes);
     assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetConfigMaps);
@@ -798,6 +832,10 @@ mod tests {
       sync_io_rx.recv().await.unwrap(),
       IoEvent::GetServiceAccounts
     );
+    assert_eq!(
+      sync_io_rx.recv().await.unwrap(),
+      IoEvent::GetNetworkPolicies
+    );
     assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetMetrics);
     assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetNamespaces);
     assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetNodes);
@@ -832,6 +870,10 @@ mod tests {
     assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetKubeConfig);
     assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetNamespaces);
     assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetPods);
+    assert_eq!(
+      sync_io_rx.recv().await.unwrap(),
+      IoEvent::DiscoverDynamicRes
+    );
     assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetServices);
     assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetNodes);
     assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetConfigMaps);
