@@ -44,6 +44,12 @@ pub struct StatefulList<T> {
 }
 
 impl<T> StatefulList<T> {
+  pub fn new() -> StatefulList<T> {
+    StatefulList {
+      state: ListState::default(),
+      items: Vec::new(),
+    }
+  }
   pub fn with_items(items: Vec<T>) -> StatefulList<T> {
     let mut state = ListState::default();
     if !items.is_empty() {
@@ -84,7 +90,7 @@ impl<T> Scrollable for StatefulList<T> {
   }
 }
 
-#[derive(Clone)]
+#[derive(Clone, Debug)]
 pub struct StatefulTable<T> {
   pub state: TableState,
   pub items: Vec<T>,
