@@ -92,6 +92,9 @@ fn handle_escape(app: &mut App) {
         if let ActiveBlock::More = app.get_prev_route().active_block {
           app.pop_navigation_stack();
         }
+        if let ActiveBlock::DynamicView = app.get_prev_route().active_block {
+          app.pop_navigation_stack();
+        }
       }
     },
   }
@@ -217,6 +220,10 @@ async fn handle_route_events(key: Key, app: &mut App) {
           let route = app.context_tabs.set_index(9).route.clone();
           app.push_navigation_route(route);
         }
+        _ if key == DEFAULT_KEYBINDING.jump_to_dynamic_resources.key => {
+          let route = app.context_tabs.set_index(10).route.clone();
+          app.push_navigation_route(route);
+        }
         _ => {}
       };
 
@@ -402,6 +409,41 @@ async fn handle_route_events(key: Key, app: &mut App) {
             }
           }
         }
+        ActiveBlock::DynamicView => {
+          if key == DEFAULT_KEYBINDING.submit.key {
+            if let Some((title, active_block)) = app
+              .dynamic_resources_menu
+              .state
+              .selected()
+              .map(|i| app.dynamic_resources_menu.items[i].clone())
+            {
+              app.push_navigation_route(Route {
+                id: RouteId::Home,
+                active_block,
+              });
+              let selected = app.data.dynamic_kinds.iter().find(|&it| it.kind == title);
+              app.data.selected.dynamic_kind = selected.cloned();
+              app.data.dynamic_resources.set_items(vec![]);
+            }
+          }
+        }
+        ActiveBlock::DynamicResource => {
+          if let Some(dynamic_res) = app.data.selected.dynamic_kind.as_ref() {
+            if let Some(res) = handle_block_action(key, &mut app.data.dynamic_resources) {
+              let _ok = handle_describe_decode_or_yaml_action(
+                key,
+                app,
+                &res,
+                IoCmdEvent::GetDescribe {
+                  kind: dynamic_res.kind.to_owned(),
+                  value: res.name.to_owned(),
+                  ns: res.namespace.to_owned(),
+                },
+              )
+              .await;
+            }
+          }
+        }
         ActiveBlock::CronJobs => {
           if let Some(res) = handle_block_action(key, &mut app.data.cronjobs) {
             let _ok = handle_describe_decode_or_yaml_action(
@@ -582,6 +624,21 @@ async fn handle_route_events(key: Key, app: &mut App) {
             .await;
           }
         }
+        ActiveBlock::NetworkPolicies => {
+          if let Some(res) = handle_block_action(key, &mut app.data.nw_policies) {
+            let _ok = handle_describe_decode_or_yaml_action(
+              key,
+              app,
+              &res,
+              IoCmdEvent::GetDescribe {
+                kind: "networkpolicy".to_owned(),
+                value: res.name.to_owned(),
+                ns: Some(res.namespace.to_owned()),
+              },
+            )
+            .await;
+          }
+        }
         ActiveBlock::Contexts | ActiveBlock::Utilization | ActiveBlock::Help => { /* Do nothing */ }
       }
     }
@@ -653,10 +710,13 @@ async fn handle_block_scroll(app: &mut App, up: bool, is_mouse: bool, page: bool
     ActiveBlock::Pv => app.data.pvs.handle_scroll(up, page),
     ActiveBlock::Ingress => app.data.ingress.handle_scroll(up, page),
     ActiveBlock::ServiceAccounts => app.data.service_accounts.handle_scroll(up, page),
+    ActiveBlock::NetworkPolicies => app.data.nw_policies.handle_scroll(up, page),
+    ActiveBlock::DynamicResource => app.data.dynamic_resources.handle_scroll(up, page),
     ActiveBlock::Contexts => app.data.contexts.handle_scroll(up, page),
     ActiveBlock::Utilization => app.data.metrics.handle_scroll(up, page),
     ActiveBlock::Help => app.help_docs.handle_scroll(up, page),
     ActiveBlock::More => app.more_resources_menu.handle_scroll(up, page),
+    ActiveBlock::DynamicView => app.dynamic_resources_menu.handle_scroll(up, page),
     ActiveBlock::Logs => {
       app.log_auto_scroll = false;
       app.data.logs.handle_scroll(inverse_dir(up, is_mouse), page);
