@@ -9,7 +9,7 @@ use k8s_openapi::{
       ConfigMap, Namespace, Node, PersistentVolume, PersistentVolumeClaim, Pod,
       ReplicationController, Secret, Service, ServiceAccount,
     },
-    networking::v1::Ingress,
+    networking::v1::{Ingress, NetworkPolicy},
     rbac::v1::{ClusterRole, ClusterRoleBinding, Role, RoleBinding},
     storage::v1::StorageClass,
   },
@@ -36,6 +36,7 @@ use crate::app::{
   ingress::KubeIngress,
   jobs::KubeJob,
   metrics::{self, KubeNodeMetrics},
+  network_policies::KubeNetworkPolicy,
   nodes::KubeNode,
   ns::KubeNs,
   pods::KubePod,
@@ -226,7 +227,6 @@ impl<'a> Network<'a> {
 
   pub async fn get_services(&self) {
     let items: Vec<KubeSvc> = self.get_namespaced_resources(Service::into).await;
-
     let mut app = self.app.lock().await;
     app.data.services.set_items(items);
   }
@@ -361,6 +361,13 @@ impl<'a> Network<'a> {
     app.data.service_accounts.set_items(items);
   }
 
+  pub async fn get_network_policies(&self) {
+    let items: Vec<KubeNetworkPolicy> = self.get_namespaced_resources(NetworkPolicy::into).await;
+
+    let mut app = self.app.lock().await;
+    app.data.nw_policies.set_items(items);
+  }
+
   /// calls the kubernetes API to list the given resource for either selected namespace or all namespaces
   async fn get_namespaced_resources<K: ApiResource, T, F>(&self, map_fn: F) -> Vec<T>
   where
@@ -386,6 +393,7 @@ impl<'a> Network<'a> {
     }
   }
 
+  /// calls the kubernetes API to list the given resource for all namespaces
   async fn get_resources<K: ApiResource, T, F>(&self, map_fn: F) -> Vec<T>
   where
     <K as ApiResource>::DynamicType: Default,
