@@ -1,4 +1,5 @@
 // adapted from https://github.com/Rigellute/spotify-tui
+mod dynamic_resource;
 mod kube_api;
 pub(crate) mod stream;
 
@@ -38,6 +39,9 @@ pub enum IoEvent {
   GetServiceAccounts,
   GetMetrics,
   RefreshClient,
+  DiscoverDynamicRes,
+  GetDynamicRes,
+  GetNetworkPolicies,
 }
 
 async fn refresh_kube_config(context: &Option<String>) -> Result<kube::Client> {
@@ -190,6 +194,15 @@ impl<'a> Network<'a> {
       IoEvent::GetServiceAccounts => {
         self.get_service_accounts().await;
       }
+      IoEvent::GetNetworkPolicies => {
+        self.get_network_policies().await;
+      }
+      IoEvent::DiscoverDynamicRes => {
+        self.discover_dynamic_resources().await;
+      }
+      IoEvent::GetDynamicRes => {
+        self.get_dynamic_resources().await;
+      }
     };
 
     let mut app = self.app.lock().await;
